@@ -1,13 +1,15 @@
 \donttest{
-if (bru_safe_inla(multicore = FALSE) &&
+if (bru_safe_inla() &&
     bru_safe_sp() &&
     require("sp") &&
     require("sn", quietly = TRUE) &&
-    require("ggplot2", quietly = TRUE)) {
+    require("ggplot2", quietly = TRUE) &&
+    require("terra", quietly = TRUE) &&
+    require("sf", quietly = TRUE)) {
 
   # Load the Gorilla data
 
-  data(gorillas, package = "inlabru")
+  gorillas <- gorillas_sp()
 
   # Plot the Gorilla nests, the mesh and the survey boundary
 
